#! /bin/sh
### BEGIN INIT INFO
# Provides:          mountnfs nfs
# Required-Start:    $network $local_fs
# Required-Stop:
# Default-Start:     S
# Default-Stop:
# Short-Description: Mount network file systems
# Description:       Now that TCP/IP is configured, mount the NFS file
#                    systems in /etc/fstab if needed. If possible,
#                    start the portmapper before mounting (this is needed for
#                    Linux 2.1.x and up).
#
#                    Also mounts SMB filesystems now, so the name of
#                    this script is getting increasingly inaccurate.
### END INIT INFO
#
# Version:	@(#)mountnfs.sh  2.86-5  10-Sep-2004  miquels@cistron.nl
#

[ -z "VERBOSE" ] && VERBOSE=yes
[ -z "TMPTIME" ] && TMPTIME=0
[ -f /etc/default/rcS ] && . /etc/default/rcS
. /etc/init.d/bootclean.sh
. /lib/lsb/init-functions

do_start () {
	#
	#	Run in a subshell because of I/O redirection.
	#
	test -f /etc/fstab && (

	#
	#	Read through fstab line by line. If it is NFS, set the flag
	#	for mounting NFS file systems. If any NFS partition is found and it
	#	not mounted with the nolock option, we start the portmapper.
	#
	portmap=no
	while read device mountpt fstype options
	do
		case "$device" in
			""|\#*)
				continue
				;;
		esac

		case "$options" in
			*noauto*)
				continue
				;;
		esac

		case "$fstype" in
			nfs|nfs4)
				case "$options" in
					*nolock*)
						;;
					*)
						portmap=yes
						;;
				esac
				;;
			smbfs|cifs|coda|ncp|ncpfs|ocfs2|gfs)
				;;
			*)
				fstype=
				;;
		esac
		if [ -n "$fstype" ]
		then
			case "$NETFS" in
				$fstype|*,$fstype|$fstype,*|*,$fstype,*)
					;;
				*)
					NETFS="$NETFS${NETFS:+,}$fstype"
					;;
			esac
		fi
	done

	exec 0>&1

	if [ "$portmap" = yes ]
	then
		if [ -x /sbin/portmap ] && [ -z "`pidof portmap`" ] 
		then
			if [ -x /etc/init.d/portmap ] 
			then
				/etc/init.d/portmap start
		        else
				log_begin_msg "Starting portmap..."
				start-stop-daemon --start --quiet --exec /sbin/portmap
				sleep 2
				log_end_msg $?
			fi
		fi
	fi

	if [ -n "$NETFS" ]
	then
	(
		log_begin_msg "Mounting remote filesystems..."
		if mount -a -t$NETFS ; then
			log_end_msg 0
		else
			log_end_msg 1
		fi
	) 2>&1 | egrep -v '(already|nothing was) mounted'
	fi

	) < /etc/fstab

	#
	#       Clean /tmp, /var/lock, /var/run
	#
	bootclean mountnfs
}

case "$1" in
    start)
    	do_start
	;;
    *)
        ;;
esac

: exit 0

